@@ -1,7 +1,7 @@
 ;;; misc-tests.lisp
 ;;;
 ;;; Copyright (C) 2005 Peter Graves
-;;; $Id: misc-tests.lisp 12935 2010-10-02 07:36:08Z ehuelsmann $
+;;; $Id$
 ;;;
 ;;; This program is free software; you can redistribute it and/or
 ;;; modify it under the terms of the GNU General Public License
@@ -109,3 +109,12 @@
                                          x)
                                  (values 42 2))))))
   42 2)
+
+(deftest string-output-stream.seekable
+    (string= "Goodbye, World! Something."
+             (let ((stream (make-string-output-stream)))
+               (write-string "Hello, World!   Something." stream)
+               (file-position stream :start)
+               (write-string "Goodbye, World!" stream)
+               (get-output-stream-string stream)))
+  T)
